SystemOrganization addCategory: #'Neo4reSt-Pharo-Core'!

N4PortableUtil subclass: #N4PhPortableUtil
	instanceVariableNames: 'httpClient'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Neo4reSt-Pharo-Core'!

!N4PhPortableUtil class methodsFor: 'class initialization' stamp: 'mu 11/27/2011 16:17'!
initialize
	self activate! !

!N4PhPortableUtil methodsFor: 'converting' stamp: 'MasashiUmezawa 6/2/2012 22:56'!
convertToNative: value using: settings
	value isString ifTrue: [^ self nativeStringFrom: value].
	^value
! !

!N4PhPortableUtil methodsFor: 'factories' stamp: 'MasashiUmezawa 6/2/2012 22:56'!
createHttpClient
	^ZnClient new! !

!N4PhPortableUtil methodsFor: 'converting' stamp: 'MasashiUmezawa 4/22/2012 22:43'!
dictionaryFromAssociations: assocs
	^ assocs asDictionary
	! !

!N4PhPortableUtil methodsFor: 'accessing' stamp: 'MasashiUmezawa 6/2/2012 22:56'!
ensuredHttpClient
	(httpClient notNil and: [httpClient isConnected not]) ifTrue: [self releaseHttpClient].
	httpClient ifNil: [httpClient := self createHttpClient].
	^httpClient
	! !

!N4PhPortableUtil methodsFor: 'actions' stamp: 'mu 12/23/2011 13:05'!
getJsonFrom: urlString 
	| response |
	response := self httpJsonGet: urlString.
	^self readJsonFromResponse: response! !

!N4PhPortableUtil methodsFor: 'accessing' stamp: 'MasashiUmezawa 6/2/2012 22:55'!
httpClient
	
	^  N4Settings default keepConnection
		ifTrue: [self ensuredHttpClient]
		ifFalse: [self createHttpClient]
! !

!N4PhPortableUtil methodsFor: 'accessing' stamp: 'MasashiUmezawa 6/2/2012 22:54'!
httpClient: anObject
	httpClient := anObject! !

!N4PhPortableUtil methodsFor: 'actions-http' stamp: 'mu 12/4/2011 15:59'!
httpJsonDelete: urlString 
	| resp |
	resp := self httpClient jsonDelete: urlString.
	resp code = 409 ifTrue: [^N4CannotDelete response: resp].
	^ resp! !

!N4PhPortableUtil methodsFor: 'actions-http' stamp: 'mu 11/29/2011 23:00'!
httpJsonGet: urlString
	| resp |
	resp := self httpClient jsonGet: urlString.
	self signalErrorBasedOn: resp.
	^ resp! !

!N4PhPortableUtil methodsFor: 'actions-http' stamp: 'mu 11/27/2011 16:36'!
httpJsonPost: urlString
	
	^ self httpClient jsonPost: urlString! !

!N4PhPortableUtil methodsFor: 'actions-http' stamp: 'mu 11/27/2011 16:52'!
httpJsonPost: urlString content: jsonString
	
	^ self httpClient jsonPost: urlString content: jsonString! !

!N4PhPortableUtil methodsFor: 'actions-http' stamp: 'mu 12/2/2011 00:03'!
httpJsonPut: urlString content: jsonString
	
	^ self httpClient jsonPut: urlString content: jsonString! !

!N4PhPortableUtil methodsFor: 'read/write' stamp: 'MasashiUmezawa 6/2/2012 22:54'!
jsonStringFrom: valueOrAssocs 
	| dict rawJsonString param |
	((valueOrAssocs isArray or: [valueOrAssocs class = OrderedCollection])
		and: [valueOrAssocs notEmpty and: [valueOrAssocs first isKindOf: Association]])
		ifTrue: [dict := valueOrAssocs asDictionary.
			param := dict]
		ifFalse: [param := valueOrAssocs].
	rawJsonString := Json render: param.
	^ rawJsonString! !

!N4PhPortableUtil methodsFor: 'read/write' stamp: 'MasashiUmezawa 6/2/2012 22:57'!
nativeStringFrom: utf8String
	^ utf8String convertFromEncoding: #utf8 ! !

!N4PhPortableUtil methodsFor: 'actions' stamp: 'mu 11/27/2011 16:39'!
postJson: json to: urlString

	! !

!N4PhPortableUtil methodsFor: 'actions' stamp: 'mu 11/27/2011 16:41'!
postJsonTo: urlString
	^self readJsonFrom: (self httpJsonPost: urlString) contentStream! !

!N4PhPortableUtil methodsFor: 'read/write' stamp: 'mu 11/27/2011 16:39'!
readJsonFrom: aStream

	^ Json readFrom: aStream! !

!N4PhPortableUtil methodsFor: 'actions' stamp: 'MasashiUmezawa 4/22/2012 14:39'!
readJsonFromResponse: httpResponse
	| strm |
	strm := httpResponse contents readStream.
	^ self readJsonFrom: strm! !

!N4PhPortableUtil methodsFor: 'releasing' stamp: 'MasashiUmezawa 6/2/2012 22:53'!
release
	self releaseHttpClient! !

!N4PhPortableUtil methodsFor: 'releasing' stamp: 'MasashiUmezawa 6/2/2012 22:59'!
releaseHttpClient
	httpClient ifNotNil: [httpClient close].
	httpClient := nil
! !

!N4PhPortableUtil methodsFor: 'error handling' stamp: 'mu 11/29/2011 22:59'!
signalErrorBasedOn: response
	| code |
	code := response code.
	(code between: 200 and: 203) ifTrue: [^self].
	code = 204 ifTrue: [^ (N4NoContent response: response) signal].
	code = 404
		ifTrue: [^ (N4NotFound response: response) signal].
	^ (N4Error response: response) signal! !

!N4PhPortableUtil methodsFor: 'misc utils' stamp: 'mu 11/27/2011 23:58'!
string: aString beginsWith: prefix 
	^ aString beginsWith: prefix ! !

!N4PhPortableUtil methodsFor: 'read/write' stamp: 'MasashiUmezawa 4/22/2012 14:35'!
utf8StringFrom: squeakString
	^ squeakString convertToEncoding: #utf8 ! !

!ZnClient methodsFor: '*Neo4reSt-Pharo-Core' stamp: 'MasashiUmezawa 4/22/2012 15:12'!
contentType: aString
	self request headers at: 'Content-Type' put: aString! !

!ZnClient methodsFor: '*Neo4reSt-Pharo-Core' stamp: 'MasashiUmezawa 4/22/2012 14:27'!
jsonDelete: urlString
	self accept: 'application/json'.
	self delete: urlString.
	^self response! !

!ZnClient methodsFor: '*Neo4reSt-Pharo-Core' stamp: 'MasashiUmezawa 4/22/2012 14:22'!
jsonGet: urlString
	self accept: 'application/json'.
	self get: urlString.
	^self response! !

!ZnClient methodsFor: '*Neo4reSt-Pharo-Core' stamp: 'MasashiUmezawa 4/22/2012 14:40'!
jsonPost: urlString
	^ self jsonPost: urlString content: ''! !

!ZnClient methodsFor: '*Neo4reSt-Pharo-Core' stamp: 'MasashiUmezawa 4/22/2012 15:31'!
jsonPost: urlString content: jsonString
	self accept: 'application/json'.
	self contentWriter: [:o | (ZnEntity with: o) contentType: 'application/json; charset=utf-8'].
	self post: urlString contents: jsonString.
	^self response! !

!ZnClient methodsFor: '*Neo4reSt-Pharo-Core' stamp: 'MasashiUmezawa 4/22/2012 15:31'!
jsonPut: urlString content: jsonString
	self accept: 'application/json'.
	self contentWriter: [:o | (ZnEntity with: o) contentType: 'application/json; charset=utf-8'].
	self put: urlString contents: jsonString.
	^self response! !
N4PhPortableUtil initialize!
